# -*- coding: utf-8 -*-

__author__ = """Vu Anh"""
__email__ = 'brother.rain.1024@gmail.com'
__version__ = '1.0.0'


def info(version):
    """Show information about underthesea package

    :param str version: version of package
    :type version: str
    """
    print(version)
    print("underthesea is a Vietnamese NLP Toolkit")



class Document:
    def __init__(self, id):
        """
        :param id id of document
        :type id: str
        """
        self.id = id
        self.sentences = None

    def set_sentences(self, sentences):
        self.sentences = sentences



# -*- coding: utf-8 -*-
def hi():
    print("Hello")


class Corpus:
    """
    Corpus is fundamental resource of NLP
    """
    def __init__(self):
        print("Corpus is fundamental resource of NLP")
